==> haskell-wai-middleware-static-0.9.3-150-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-middleware-static
version:              0.9.3
visibility:           public
id:                   wai-middleware-static-0.9.3-4Qn8B47gasaJ5omXojNAOH
key:                  wai-middleware-static-0.9.3-4Qn8B47gasaJ5omXojNAOH
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  c99b9fffd0d0398f0983a59a525e53b8
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.3-4Qn8B47gasaJ5omXojNAOH
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-ASFphLrgXvi67bm2qxzorY
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-24zEmBYT7AR5XuoQwLI2BZ directory-1.3.7.1
    expiring-cache-map-0.0.6.1-Hcma371fejh1dQvKbO1h0q filepath-1.4.2.2
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2 time-1.12.2
    wai-3.2.4-LnpkwzoHUW9G2cGUC0nKUm

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-middleware-static-0.9.3-177-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-middleware-static
version:              0.9.3
visibility:           public
id:                   wai-middleware-static-0.9.3-F5t3siu4Jur3GaB1uQmqag
key:                  wai-middleware-static-0.9.3-F5t3siu4Jur3GaB1uQmqag
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  e32bbd9eacdb6a0b029881a6f33be340
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.3-F5t3siu4Jur3GaB1uQmqag
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-1Uz6oHjhPf9KewF5fWee2u
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-ABJXCufxSvFHV6sCEE1AN3 directory-1.3.7.1
    expiring-cache-map-0.0.6.1-55obXaBrxFO1dAaX3KvvD filepath-1.4.2.2
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2 time-1.12.2
    wai-3.2.4-GKgviHtnWhO3KoBTtmAmpl

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
